@@ -6,6 +6,7 @@ from GuardiPy.helpers import CentraEntity, CentraApiPayload
 class User(CentraEntity):
     _path = "/system/user"
 
+    # Add user
     @staticmethod
     def add(
             username: str,
@@ -17,7 +18,6 @@ class User(CentraEntity):
             description: str = None,
             is_saml_user: bool = False,
     ) -> CentraApiPayload:
-    
         data = {
             "action": "create",
             "username": username,
@@ -35,6 +35,18 @@ class User(CentraEntity):
                                    data=data, response_pagination=False)
         return payload
 
+    # Delete user
+    @staticmethod
+    def delete(username: str) -> CentraApiPayload:
+        data = {
+            "action": "delete",
+            "confirm": True,
+            "username": username
+        }
+
+        return CentraApiPayload(path=User._path, method="POST", return_type=User,
+                                data=data, response_pagination=False)
+
     def __init__(self, **kwargs):
         logging.debug("New Attributes found for User")
         for k, v in kwargs:
